--- Guilder: Version Checker Module
-- This module allows the user to query the versions of raiding addons installed on another member of the group's computer.
-- @class file
-- @name Modules/Version.lua
-- @release 2.1.x

--[[
   Copyright 2009 Christo Kotze (onaforeignshore)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
]]

if select(6, GetAddOnInfo("Guilder_" .. (debugstack():match("[o%.][d%.][u%.]les\\(.-)\\") or ""))) ~= "MISSING" then return end

local Guilder = _G.Guilder
if not Guilder then
  error("Guilder_Version requires Guilder")
end
local L = LibStub("AceLocale-3.0"):GetLocale("Guilder/Version")

local DEBUG = Guilder.DEBUG
local expect = Guilder.expect

-- default settings for the addon -------------------------------------------

local DATABASE_DEFAULTS = {
	channel = "",
	player = "",
	queryOmen = true,
	queryRecount = true,
	queryBigWigs = true,
	queryDBM = true,
	queryDXE = true,
	queryLHC30 = true,
	queryLHC40 = true,
	includeRevision = false
}

-- declare the module -------------------------------------------------------

local Guilder_Version = Guilder:NewModule("Version", "AceEvent-3.0", "AceHook-3.0")
Guilder_Version:SetName(L["Version Checker"])
Guilder_Version:SetDescription(L["Check addon versions."])
Guilder_Version:SetDefaults(DATABASE_DEFAULTS)
if DEBUG then
	Guilder_Version:SetIcon([[Interface\AddOns\Guilder\Modules\Version\Version]])
else
	Guilder_Version:SetIcon([[Interface\AddOns\Guilder_Version\Version]])
end

-- local variables ----------------------------------------------------------

-- boss mod versions
local addons = {
	BigWigs = {},
	DBM = {},
	DXE = {},
	LHC30 = {},
	LHC40 = {}
}

--[===[@debug@
Guilder.addons = addons

local Debug = Guilder.Debug

local knownPrefix = {
	-- Unknown
	--	["GSCR"] = not GearScore :(
	--	["\016X{"] = "UNKNOWN_8_[\016X{]",--warrior-raid
	--	["\175\150\155"] = "UNKNOWN_6_[\175\150\155]", -- Hunter_whisper", 
	--	["\235\1742"] = "UNKNOWN_4_[235\1742]!!!",-- looks like a typo!
	--	["]\027L"] = "UNKNOWN_7!!_[]\027L]", -- paladin-bg
	--	["}\027L"] ="UNNOWN_12!!!_[}\027L",] ]]--
	--	["b\146F"] = "UNKNOWN_2!!!_[b\146F]",
	--	["BGSAlertsVersion"] = "UNKNOWN_9!!!_[BGSAlertsVersion]",
	--	["KS2"]= "UNKNOWN_10!!!_KS2",
	--	["LW\190"] = "UNKNOWN_5!!_[LW\190]", --mage_raid",
	--	["v`\153"] = "UNKNOWN_3!!_[v'\153]",--warlock_raid"
	--	[	[vgcomm+X = VGComms (curse)]]--
	-- AceComm Hashes
	["\137\016"] = "Cartographer [Notes]",
	[")\252$"] = "AceComm [VersionCheck]", -- Hash of "Version". VersionChecker also used
	[".\136="] = "Proximo",
	["\130\131\213"] = "Boss Talk",
	["\143\019\007"] = "SpamMeNot",
	["\1484\008"] = "VanasKoS",
	["\1613	["] = "BagPress",
	["\1675B"] = "Recap",
	--["\1813T"] = "Recount",
	["\198\137h"] = "Violation",
	["\198\232\192"] = "CooldownTimers2",
	--["\229^\092"] = "ZOMGBuffs",
	["\234\218\230"] = "Gladiator",
	["\252\245G"] = "QuestsFu",
	["2\224\237"] = "Cartographer [Guild Positions]",
	["8\206\194"] ="VoiceFU",
	["h\031Y"] = "InventoryLib-2.0",
	["k\227D"] = "GPSLib",
	["p\190\246"] = "SimpleMD",
	["R\195\159"] = "RecipeBook",
	-- Human readable prefixes
	["^RX^"] = "Prescription_Pickup",
	["<<PiraCore>>"] = "PiraMod",
	["AGC"] = "AthenesGearCheck",
	["ALF_T"] = "Arena Live Frames",
	["AlgalonObserver"] = "AlgalonObserver",
	["AltoGuild"] = "Altoholic",
	["Altoholic"] = "Altoholic",
	["AM_FU"] = "AlphaMap",
	["ArenaMaster"] = "Arena Master",
	["ArenaUnitFrames"] = "Arena Unit Frames",
	["Armory"] = "Armory",
	["ATf"] = "AutoFIR",
	["ATF"] = "AutoFIR",
	["ATm"] = "AutoFIR",
	["ATR"] = "Auctionator",
	["AucAdvAskPrice"] = "Auctioneer",
	["Audio Effects"] = "AFX",
	["BangCore_TPO"] = "Bang!Core",
	["BangWG5"] = "BangWintergrasp",
	["BE2"] = "BossEncounter2",
	["BeastTraining"] = "BeastTraining",
	["BEJ2a"] = "Bejeweled",
	["BEJEWELED2"] = "Bejeweled",
	["BFC"] = "Battlefield Commander",
	["BGGQ"] = "Gladiator",
	["BigWigs"] = "BigWigs",
	["BOSSTACTICS"] = "BossTactics",
	["BrokerEpicAvg"] = "Broker:EpicAvg",
	["BST"] = "Bonstar",
	["BWOOD"] = "BigWigs", -- BigWigs version broadcast
	["BWOOD3"] = "BigWigs 3",
	["BWTIP"] = "BigWigs 3",
	["BWVB"] = "BigWigs", -- BigwWigs version query
	["BWVB2"] = "BigWigs", -- BigWigs version query v2
	["BWVQ"] = "BigWigs", -- BigWigs version query
	["BWVQ3"] = "BigWigs 3",
	["BWVR"] = "BigWigs", -- BigWigs version response
	["BWVR3"] = "BigWigs 3",
	["BWVRA3"] = "BigWigs 3",
	["CaN"] = "Cartographer [Notes]",
	["cap"] = "Capping",
	["Cap"] = "Capping_v3.2.002+",-- new IoC siege sync
	["CastCommLib"] = "CastCommLib",
	["CB"] = "VoidReaverAlarm", -- 10sec normal mode
	["CFUVCQ"] ="FuBar_ConvergeFU",
	["CFUVCR"] ="FuBar_ConvergeFU",   
	["CGP"] = "Cartographer [Guild Positions]",
	["chatmod"] = "ChatMOD",
	["CKICK_SYNC"] = "Ckick", 
	["Crb"] = "CarboniteQuest",
	["CT"] = "VoidReaverAlarm",--60sec test mode
	["CT3"] = "Cartographer 3",
	--["CTRA"] = "CTRaidAssist",
	["D?"] = "ControlArena",
	--["DamageMeters"] = "DamageMeters",
	["DataStore"] = "DataStore",
	["DBMv4-CombatInfo"] = "DBM v4",
	["DBMv4-Kill"] = "DBM v4",
	["DBMv4-Mod"] = "DBM v4",
	["DBMv4-Pizza"] = "DBM v4",
	["DBMv4-Pull"] = "DBM v4",
	["DBMv4-RequestTimers"] = "DBM v4",
	["DBMv4-TimerInfo"] = "DBM v4",
	["DBMv4-Ver"] = "DBM v4",
	["Death_Tracker"] = "Death_Tracker",
	["dgks_BGVersionCheckRequest"] = "dG Killshot Notifier",
	["dgks_GuildVersionCheckRequest"] = "dG Killshot Notifier",
	["dgks_KilledSoundEvent"] = "dG Killshot Notifier",
	["dgks_RaidVersionCheckRequest"] = "dG Killshot Notifier",
	["dgks_ScrollingTextEvent"] = "dG Killshot Notifier",
	["dgks_txt"] = "dG Killshot Notifier",
	["dgks_VersionCheckResponse"] = "dG Killshot Notifier",
	["DoIKnowYou"] = "DoIKnowYou",
	["DPM"] = "Deadly Pvp Mods",
	["DPMcheck"] = "Deadly Pvp Mods",
	["DPMtrue"] = "Deadly Pvp Mods",
	["DPMversion"] = "Deadly Pvp Mods",
	["DQT"] = "DaylieQuestViewer",
	["DRA2"] = "DruidRaidAssist2",
	["DRA2_ASK"] = "DruidRaidAssist2",
	["DS_Cont"] = "DataStore",
	["DS_Craft"] = "DataStore",
	["DS_Inv"] = "DataStore",
	["DS_Mails"] = "DataStore",
	["DTMR"] = "DoTimer",
	["EASYMOTHER"] = "EasyMother",
	["EnsidiaFails"] = "EnsidiaFails",
	["EPGPLMVChk"] = "EPGPLootmaster",
	["EPGPLMVHdlr"] = "EPGPLootmaster",
	["EPGPLMVRsp"] = "EPGPLootmaster",
	["ExaminerGlyphs"] = "Examiner",
	--["eXtremeRaid"] = "OnRaid",
	["FBAM"] = "Fishing Buddy",
	--["ForteWarlock"] = "ForteXorcist",
	["Gatherer"] = "Gatherer",
	["GathX"] = "Gatherer",
	--["GC3"] = "GroupCalendar",
	--["GC3/"] = "GroupCalendar",  -- Does this one actually get sent?
	--["GC4"] = "GroupCalendar",
	--["GC4/"] = "GroupCalendar",  -- Does this one actually get sent?
	--["GC5"] = "GroupCalendar",
	--["GDALootlist"] = "GetDKP",
	["GearScore"] = "GearScore",
	["GearScore_Request"] = "GearScore",
	["GearScore_Send"] = "GearScore",
	["GearScore_Version"] = "GearScore",
	["GearScoreRecount"] = "GearScore",
	--["GEM3"] = "GuildEventManager",
	["GLDG"] = "GuildGreet",
	["GMSD"] = "GatherMate Sharing",
	["GoGoMountVER"] = "GoGoMount",
	["gqAccept"] = "Guild Quests",
	["gqLogout"] = "Guild Quests",
	["gqRemove"] = "Guild Quests",
	["gqReply"] = "Guild Quests",
	["GSX"] = "GearScore",
	["GSY"] = "GearScore",
	["GSY_Request"] = "GearScore",
	["GSY_Version"] = "GearScore",
	["GTH"] = "Getting Things Healed",
	["GuildCraft3"] ="GuildCraft",
	["GUILDMAP"] = "GuildMap",
	["GuildSpyVersion"] = "GuildSpy",
	["GupPetVersion"] = "GupPet",
	--["hbComms"] = "HealBot_Ultra_low_comms",
	--["hbGUID"] = "HealBot",
	--["HealBot"] = "HealBot",
	--["HealBot_GUID"] = "HealBot",
	--["HealBot_Heals"] = "HealBot",
	--["HealComm"] = "LibHealComm-3.0",-- or version2, you cant tell them apart
	["HIVE"] = "HiveMind",
	--["IHL"] = "IncomingHealsLib-1.0",
	["JambaCommunicationsCommand"] = "Jamba", --multiboxing tool
	["KALIFCMSG"] = "Forecast",
	["KARMA"] = "Karma",
	["kEl"] = "DalaranUniversity",
	["KHP_deamon"] = "Kalecgos Dual HP",
	["KHP_dragon"] = "Kalecgos Dual HP",
	["KLHALG"] = "KLHAlgalon", --check
	--["KLHTM"] = "KLHThreatMeter",
	["LGP"] = "LibGuildPositions-1.0",
	--["LHC40"] = "LibHealComm-4.0",
	["LibGroupTalents-1.0"] = "LibGroupTalents-1.0",
	["Lockdown0005Hello"] = "Lockdown",
	["Lockdown0005NewLock"] = "Lockdown",
	["Lockdown0005Wipe"] = "Lockdown",
	["LockdownUpdate"] = "Lockdown",
	["LOOT_OPENED"] = "AceEvent-2.0 [Loot Opened]",
	["LootFilter"] ="LootFilter",
	--["LPH10"] = "LibPendingHeals-1.0",
	--["LRW2"] = "LiveRaidWatch_v2",
	["lugMD"] = "lugMD",
	["LVBM NSP"] = "Deadly Boss Mods",
	["LVBM NSP"] = "Deadly Boss Mods",
	["LVBM"] = "Deadly Boss Mods",
	["LVFH MARK"] = "Deadly Boss Mods",
	["LVFH VOID"] = "Deadly Boss Mods",
	["LVGWF ENRAGE"] = "Deadly Boss Mods",
	["LVNEF"] = "Deadly Boss MOds",
	["MageMajic"]  ="MageMajic",
	["MagicMarker"] = "MagicMarker",
	["MagicMarker"] = "MagicMarker",
	["MagicMarkerRT"] = "MagicMarker",
	["MalygosFlamer"] = "MalygosFlamer",
	["MalygosFlamerVersion"] = "MalygosFlamer",
	["MeBO"] = "MessageBoard", --most likely
	--["MLRA"] = "CT_RaidTracker",
	["mmkocomm"] = "MM Kill Order",--check! 
	["MorgBid2"] = "MorgBid2",
	["MorgDKP2MorgBid"] = "MorgDKP2",
	["MorgDKP2MorgBid"] = "MorgDKP2",
	["MorgDKP2Syncing"] = "MorgDKP2",
	["MS1"] = "MinnaStats",
	["MultiBoxer"] = "MultiBoxer",
	["MYC"] = "MakeYourChoice",
	["NECB"] = "Natur EnemyCastBar",
	["NECBCHAT"] = "Natur EnemyCastBar",
	["NECBCTRA"] = "Natur EnemyCastBar",
	["Nurfed:Lyt"] = "Nurfed Layout",
	--["oRA"] = "oRA2",
	--["oRA3"] = "oRA3",
	--["PALB"] = "Paladin Buffer",
	["PartyCastingBars"] = "PartyCastingBars",
	["Pit"] = "PitBull",
	--["PLPWR"] = "PallyPower",
	["PreformAVEnabler"] = "PreformAVEnabler",
	["QHpr"] = "QuestHelper",
	["QQ6"] = "TooltipExchange",  -- TooltipExchange protocol 6
	["Quecho"] = "Quecho",
	["Quecho2"] = "Quecho", --turned in
	["Quecho3"] = "Quecho", --accepted
	["QuestAnnouncer"] = "QuestAnnouncer",
	["QuGu"] = "Quest Guru",
	["Quixote2"] ="Kemayos Questlib (Libquixote-2.0)",
	--["RAB/BI"] = "RABuffs", 
	--["RAB/BR"] = "RABuffs", 
	--["RAB/BS"] = "RABuffs", 
	--["RAB/BT"] = "RABuffs",
	--["RAB/RD"] = "RABuffs", 
	--["RAB/RE"] = "RABuffs", 
	--["RAB/RF"] = "RABuffs", 
	--["RAB/RN"] = "RABuffs", 
	--["RAB/RO"] = "RABuffs", 
	--["RAB/V"]  = "RABuffs", 
	--["RAB/VC"] = "RABuffs",  
	--["RaCD"] = "RaidCooldowns",
	--["RaidForge"] = "RaidForge",
	--["RAIDMOBMARKER"] = "RaidMobMarker",
	--["RAIDTOTEMS"] = "TotemTimers",
	--["RAIDVOICE"]= "RaidVoice",
	--["RBM"] = "RBM",
	--["RCD2"] = "RaidCooldowns",
	--["RD"] = "RogueDamage",
	--["RDX"] = "OpenRDX",
	--["Recap"] = "Recap",
	--["RECOUNT"] = "Recount",
	--["RID"] = "Raid ID",
	["RTM"] = "RezzTextMonitor",
	["Rupture"] = "Rupture",
	--["SGLC"] = "SurgeonGeneral",
	["SimpleMD"] = "SimpleMD",
	["SmartRes"] = "SmartRes",
	["SMN"] = "SpamMeNot",
	--["SorrenTimers"] = "SorrenTimers",
	--["SRA"] = "SRA",
	["SRTi"] = "Simple Raid Target Icons",
	["SRTI"] = "Simple Raid Target Icons",
	["SSAF"] = "SSArena Frames",
	["SSPVP"] = "SSPVP",
	["StinkyQ"] = "StinkyQueue",
	["Super Duper Macro query"] = "Super Duper Macro",
	["Super Duper Macro recDone"] = "Super Duper Macro",
	["Super Duper Macro receiving"] = "Super Duper Macro",
	["Super Duper Macro recFailed"] = "Super Duper Macro",
	["Super Duper Macro response"] = "Super Duper Macro",
	["Super Duper Macro send1"] = "Super Duper Macro",
	["Super Duper Macro send2"] = "Super Duper Macro",
	["Super Duper Macro sendFailed"] = "Super Duper Macro",
	["SWSHSX21"] = "SW_Stats",
	["SWSHSX22"] = "SW_Stats",
	["SWSudX21"] = "SW_Stats",
	["SWSudX22"] = "SW_Stats",
	["SWSVC7w7"] = "SW_Stats",
	["TAL"] = "LibRockComm-1.0",
	["Talented"] = "Talented",
	--["Thr"] = "Threat-1.0",
	["TitanWG"] = "Titan Panel [Wintergrasp]",
	--["TL2"] = "Threat-2.0",
	--["TotemTracker"] = "TotemTracker",
	["tradeDispenser"] = "Trade Dispenser",
	["TSK"] = "TeamSqueak",
	["TypI"] = "TypingNotifier",
	["UnT"] = "LibRockComm-1.0",
	["Utopia"] = "Utopia",
	["Utopia_UpTime"] = "Utopia",
	["VA"] = "VoidReaverAlarm",--version check answer
	["VC"] = "VoidReaverAlarm", --version check request
	["VER"] = "LibRockComm-1.0",
	--["VisualHeal"] = "VisualHeal",
	["VodkaHoldem"] = "WoWTexasHoldem",
	["WGFU"] = "WintergraspFU",
	["WGTime"] = "Capping", --Wintergrasp-Sync
	["WIM"] = "WoW Instant Messenger",
	["WIM_W2W"] = "WoW Instant Messenger",
	["WintergraspT"] = "WinterTime",
	["WL_LOOT_COOLDOWN"] = "Wowhead Looter",  
	["WL_LOOTCOOLDOWN_NPC"] = "Wowhead Looter",
	["WL_LOOTCOOLDOWN_OBJECT"] = "Wowhead Looter",
	["WL_LOOTED_NPC"]  = "Wowhead Looter",
	["WQ2"] = "WoWQuote2",
	["WRUGSAUTH"] = "WRUGS Anti-Spam",
	--["X-Perl"] = "X-Perl",
	--["X-PerlHeal"] = "X-Perl",
	["XChar"] = "XChar-Profiler",
	--["Yacl"] = "YACL-DmgMeter",
	--["YRT2"] = "YamRaidTracker2",
}
--@end-debug@]===]

-- Standard Module Methods --------------------------------------------------

-- Is called when the module is loaded
-- @usage internal use only
function Guilder_Version:OnModuleLoaded(module)
	if not self.db.profile.enabled then return end
	local id = module.id
	self.db.profile.player = ""
end

-- Is called when the module is enabled
-- @usage internal use only
function Guilder_Version:OnEnable()
	-- listen in on other addons
	self:RegisterEvent("CHAT_MSG_ADDON")
end

-- Is called when the module is disabled
-- @usage internal use only
function Guilder_Version:OnDisable()
	self:UnregisterAllEvents()
end

--[[
-- Is called when the user opens the configuration screen
-- @usage internal use only
function Guilder_Version:UpdateConfigOptions()
end
]]


-- Is called when the module receives a message
-- @usage internal use only
function Guilder_Version:CommHandler(distribution, sender, command, ...)
	-- if module is disabled, do nothing
	if not self.db.profile.enabled then
		return
	end
	-- only handle comms if they are not from yourself
	-- if sender == myName then return end
	local t = {}
	local n = select("#", ...)
	-- Query: Get Version Check
	if command == "QGVC" then
		if self.db.profile.queryBigwigs then
			t["BigWigs"] = ((BigwigsLoader and L["Installed"]) or L["Not Installed!"])
		end
		if self.db.profile.queryDBM then
			t["DBM"] = ((DBM and DBM.Version) or L["Not Installed!"])
		end
		if self.db.profile.queryDBM then
			t["DXE"] = ((DXE and DXE.version) or L["Not Installed!"])
		end
		if self.db.profile.queryOmen then
			t["Omen"] = ((Omen and Omen.version) or L["Not Installed!"])
		end
		if self.db.profile.queryRecount then
			t["Recount"] = ((Recount and Recount.Version) or L["Not Installed!"])
		end
		Guilder:SendComm(self.id, "WHISPER", sender, "RGVC", t)
	end
	-- Response: Get Version Check
	if command == "RGVC" then
		-- check if the message contains a table, otherwise ignore it
		if n ~= 1 then
			if self.db.profile.showDebug then
				self:ShowMessage("RGVC had no parameters!")
			end
			return
		end
		-- get the first parameter
		local t = select(1, ...)
		-- make sure that it is a table
		if type(t) ~= "table" then
			if self.db.profile.showDebug then
				self:ShowMessage("RGVC was expecting a table!")
			end
			return
		end
		local msg = Guilder:GetClassColorString(sender).." - "
		if self.db.profile.queryBigwigs then
			msg = msg.." BigWigs: "..(t["BigWigs"] or L["Not Installed!"])
		end
		if self.db.profile.queryDBM then
			msg = msg.." DBM: "..(t["DBM"] or L["Not Installed!"])
		end
		if self.db.profile.queryDXE then
			msg = msg.." DXE: "..(t["DXE"] or L["Not installed or not enabled"])
		end
		if self.db.profile.queryOmen then
			msg = msg.." Omen: "..(t["Omen"] or L["Not Installed!"])
		end
		if self.db.profile.queryRecount then
			msg = msg.." Recount: "..(t["Recount"] or L["Not Installed!"])
		end
		Guilder:ShowMessage(msg)
	end
end

-- General functions --------------------------------------------------------

-- sort table pairs alphabetically by key
-- @param t table to be sorted
-- @param f sort function to be used (can be omitted)
-- @usage internal use only
--     for k, v in pairsByKeys(someTable) do
--         print(k.." = ".. v)
--     end
local function pairsByKeys (t, f)
	local a = {}
		for n in pairs(t) do table.insert(a, n) end
		table.sort(a, f)
		local i = 0      -- iterator variable
		local iter = function ()   -- iterator function
			i = i + 1
			if a[i] == nil then
				return nil
			else
				return a[i], t[a[i]]
			end
		end
	return iter
end

-- Receives a string and converts it into a table of arguments, using "separator" as the separator character
-- @param message the input string
-- @param separator the separator character
-- @usage Guilder:GetArgs(arg1, " ")
-- @returns table of arguments
local function GetArgs(message, separator)
	message = message or ""
	local args = {}
	local i = 0
	-- search for seperators in the string and return the separated data
	for value in string.gmatch(message, "[^"..separator.."]+") do
		i = i + 1
		args[i] = string.lower(value)
	end
	return args
end

local function VerAndRev(m, t)
	local msg = t.ver
	if Guilder_Version.db.profile.includeRevision and t.rev then
		return m..": "..msg.." ("..t.rev..")"
	else
		return m..": "..msg
	end
end

local function BigWigsVersion(prefix, message, sender)
	-- listen in on BigWigs 3 version events
	-- revision
	if not addons["BigWigs"][sender] and prefix == "BWOOD3" or prefix == "BWVQ3" or prefix == "BWVR3" or prefix == "BWVRA3" then
		addons["BigWigs"][sender] = { rev = message, ver = "3.x" }
	end
	-- listen in on BigWigs 2 version events
	-- module:revision
	if not addons["BigWigs"][sender] and prefix == "BWVB2" then
		local module, revision = select(3, message:find("(.*):(%d+)"))
		if module and revision then
			addons["BigWigs"][sender] = { rev = revision, ver = "2.x" }
		end
	end
	-- listen in on BigWigs 1 version events
	-- revision
	if not addons["BigWigs"][sender] and prefix == "BWOOD" or prefix == "BWVB" then
		addons["BigWigs"][sender] = { rev = message, ver = "1.x" }
	end
end

local function DBMVersion(prefix, message, sender)
	-- listen in on Deadly Boss Mods 4 version events
	-- revision \t version \t version \t locale
	if not addons["DXE"][sender] and prefix == "DBMv4-Ver" and message ~= "Hi!" then
		local args = GetArgs(message, "\t")
		addons["DBM"][sender] = { rev = args[1], ver = args[2] }
	end
	-- listen in on Deadly Boss Mods 3 version events
	--
	
	-- listen in on Deadly Boss Mods 2 version events
	--
	
	-- listen in on Deadly Boss Mods 1 version events
	--
	
end

local function DXEVersion(prefix, message, sender)
	-- listen in on Deus Vox Encounters version events
	-- haven't figured out DXE version events, so if we see any DXE event, the user has it installed
	if not addons["DXE"][sender] and prefix == "DXE" then
		addons["DXE"][sender] = { ver = L["Yes"] }
	end
end

local function LHCVersion(prefix, message, sender)
	-- listen in on LibHealComm-4.0 events
	-- lib doesn't actually send version info, so if we see a message from LHC4, user has it
	if not addons["LHC40"][sender] and prefix == "LHC40" then
		addons["LHC40"][sender] = { ver = L["Yes"] }
	end
	-- listen in on LibHealComm-3.0 events
	-- version information contained within the string - 998xxxxx
	if not addons["LHC30"][sender] and prefix == "HealComm" then
		local msgtype = tonumber(message:sub(1, 3))
		if (not msgtype) then return end
		if (msgtype >= 998) then -- AnnounceVersion
			local version = tonumber(message:sub(4, -1))
			if version then
				if version ~= "88888" then -- the libwrapperhealcomm version query string
					addons["LHC30"][sender] = { rev = version - 90000, ver = L["Yes"] }
				end
			else
				addons["LHC30"][sender] = { ver = L["Yes"] }
			end
		end
	end
end

-- local table of prefix to addonName
local checkAddon = {
	["BWOOD"] = "BigWigs", -- 1
	["BWOOD3"] = "BigWigs", --3
	["BWVB"] = "BigWigs", -- 1
	["BWVB2"] = "BigWigs", -- 2
	["BWVQ3"] = "BigWigs", -- 3
	["BWVR3"] = "BigWigs", -- 3
	["BWVRA3"] = "BigWigs", -- 3
	["DBMv4-Ver"] = "DBM", -- 4
	["DXE"] = "DXE",
	["HealComm"] = "LHC", -- 3
	["LHC40"] = "LHC" -- 4
}

-- Listens to other addon communications and stores information required
-- @param event not used as it should always be CHAT_MSG_ADDON
--   (only useful if you use one function for multiple events)
-- @param prefix prefix of the comm message
-- @param message the message that was sent
-- @param distribution the channel that was used
-- @param sender the person that sent the message
function Guilder_Version:CHAT_MSG_ADDON(event, prefix, message, distribution, sender)
	--[===[@debug@
	if not knownPrefix[prefix] then
		Debug("|cff9999ff"..distribution.."|r", "["..sender.."]", "|cffff00ff"..prefix.."|r ", message)
	end
	--@end-debug@]===]
	if not checkAddon[prefix] then return end -- only continue if the addon is in our check table
	if checkAddon[prefix] == "BigWigs" then BigWigsVersion(prefix, message, sender) end
	if checkAddon[prefix] == "DBM" then DBMVersion(prefix, message, sender) end
	if checkAddon[prefix] == "DXE" then DXEVersion(prefix, message, sender) end
	if checkAddon[prefix] == "LHC" then LHCVersion(prefix, message, sender) end
end

function Guilder_Version:QueryDXE()
	local groupType = "GUILD"
	if Guilder:IsInParty() then groupType = "PARTY" end
	if Guilder:IsInRaid() then groupType = "RAID" end
	Guilder:SendCommMessage("DXE", Guilder:Serialize("RequestAllVersions"), groupType)
end

-- Sends a request to all players to get the versions of raid addons installed
function Guilder_Version:QueryPlayerVersions()
	if not self.db.profile.enabled then
		Guilder:ShowMessage(L["%s is disabled"]:format("|cff00c0ff"..L["Version Checker"].."|r"))
		return
	end
	if not (self.db.profile.queryDBM or self.db.profile.queryOmen or self.db.profile.queryRecount) then
		Guilder:ShowMessage("|cff00c0ff"..L["Version Checker"].."|r - "..L["You have not chosen any addons to check for!"])
		return
	end
	if self.db.profile.channel == "GROUP" then
		if not (LibGroup:IsInGroup()) then
			Guilder:ShowMessage("|cff00c0ff"..L["Version Checker"].."|r - "..L["You are not in a group!"])
			return
		end
		Guilder:ShowMessage(L["%s is querying the group"]:format("|cff00c0ff"..L["Version Checker"].."|r"))
		Guilder:SendComm(self.id, LibGroup:GetGroupType(), myName, "QGVC")
	else
		if self.db.profile.channel == "WHISPER" and self.db.profile.player == "" then
			Guilder:ShowMessage("|cff00c0ff"..L["Version Checker"].."|r - "..L["You have to choose a player to query!"])
			return
		end
		Guilder:SendComm(self.id, self.db.profile.channel, self.db.profile.player, "QGVC")
	end
end

function Guilder_Version:ShowGroupVersions()
	if not self.db.profile.enabled then
		Guilder:ShowMessage(L["%s is disabled"]:format("|cff00c0ff"..L["Version Checker"].."|r"))
		return
	end
	if not (LibGroup:IsInGroup()) then
		Guilder:ShowMessage("|cff00c0ff"..L["Version Checker"].."|r - "..L["You are not in a group!"])
		return
	end
	local found = false
	Guilder:ShowMessage("|cff00c0ff"..L["Version Checker"].."|r - "..L["Group Boss Mod versions"])
	if self.db.profile.groupBy == "player" then
		for p, _ in LibGroup:Iterate(true) do
			local msg = ""
			for a, v in pairsByKeys(addons) do
				if self.db.profile["query"..a] and v[p] then
					msg = msg..VerAndRev(a, v[p]).." "
					found = true
				end
			end
			if found then Guilder:ShowMessage(LibGroup:GetClassHexColor(p)..p.."|r - "..msg) end
		end
		if not found then Guilder:ShowMessage(L["No addons found!"]) end
	else
		for a, v in pairsByKeys(addons) do
			local msg = ""
			for p, _ in LibGroup:Iterate(true) do
				if self.db.profile["query"..a] and v[p] then
					msg = msg..VerAndRev(p, v[p]).." "
					found = true
				end
			end
			if found then Guilder:ShowMessage("|cff33ff99"..a.."|r - "..msg) end
		end
		if not found then Guilder:ShowMessage(L["No addons found!"]) end
	end
end
